% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %                                                                       %
% %   right hand side of differential equation for                        %
% %   two coupled FitzHugh-Nagumo neurons                                 %
% %   coupling can be uni- or bidirectional                               %
% %                                                                       %
% %   written by C. Rummel, 2017/11/20                                    %
% %                                                                       %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function dxdt = FitzHughNagumo2 (x)

    global epsilon gamma v_eq       % 2D vectors
    global coupl                    % 2D matrix

    f2_sum = f2_of_v (x([1 3])+v_eq);
    f2_veq = f2_of_v (v_eq);
    
    dxdt   = [f2_sum(1) - f2_veq(1) - x(2) ...
              + coupl(2,1)*(x(3)-x(1)); ...         % x(3) drives x(1)
              epsilon(1)*(x(1)-gamma(1)*x(2)); ...
              f2_sum(2) - f2_veq(2) - x(4) ...
              + coupl(1,2)*(x(1)-x(3)); ...         % x(1) drives x(3)
              epsilon(2)*(x(3)-gamma(2)*x(4))];
          
end



function f2 = f2_of_v (v)

    global alpha                    % 2D vector

    f2 = v.*(v-alpha).*(1-v);

end

