% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %                                                                       %
% %    Matlab function for lecture                                        %
% %    "Correlation analysis of multivariate time series and              %
% %     Principle Component Analysis"                                     %
% %    by Christian Rummel                                                %
% %                                                                       %
% %    BENESCO lecture series                                             %
% %    "Signal Analysis and Brain Oscillations in Health and Disease"     %
% %    Bern, 2016/04/01                                                   %
% %    Bern, 2017/03/31                                                   %
% %                                                                       %
% %    - read and display EEG data                                        %
% %                                                                       %
% %    usage:                                                             %
% %    [tme,EEG] = display_EEG (filepath,filename, f_samp)                %
% %                                                                       %
% %    input values:                                                      %
% %    filepath   path to data directory                                  %
% %    filename   name of file containing EEG data                        %
% %               (data is assumed to be formated as ASCII text:          %
% %                L rows:    temporal samples                            %
% %                M columns: signal channels)                            %
% %    f_samp     sampling frequency in Hertz                             %
% %                                                                       %
% %    output values:                                                     %
% %    tme        vector containing time from file start in seconds       %
% %    EEG        data matrix (L rows: temp. samples, M columns: chann.)  %
% %                                                                       %
% %    written by C. Rummel, 2016/03/23                                   %
% %                                                                       %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [tme,EEG] = display_EEG (filepath,filename, f_samp)

    close all
    clc
    
    filepath
    filename
    f_samp
    
% read full EEG recording

%     EEG   = load(strcat(filepath,filename),'-ascii');
    load(strcat(filepath,filename));

    [L M] = size(EEG)           % L: number of rows, temporal samples
                                % M: number of columns, signal channels

% calculate time from file start                                
                                
    tme = (1:L)/f_samp;
    
% display signals scaled to maximal standard deviation

    EEG_std = std(EEG,0,1);
    
    figure(10);
    hold on
    for i = 1:M
        plot(tme,EEG(:,i)/max(EEG_std)/3-i);
    end
    
end


